@echo off
SETLOCAL
SETLOCAL EnableDelayedExpansion

set result=0
set errorlevel=0
set DOMY=%~dp0
set BASE=corpusfg
set cfgm=%DOMY%%BASE%
if not exist "%cfgm%" (
	echo Error: Please verify installation.
	echo %cfgm% not found.
	exit /b 1
	)
if exist "%USERPROFILE%\domy\%BASE%.ini" (set userfiles=%USERPROFILE%\domy)
if exist "%USERPROFILE%\domt\%BASE%.ini" (set userfiles=%USERPROFILE%\domt)

set graphs=%userfiles%\graphs
set plugins=%userfiles%\plugins
set rootfolder=%HOMEDRIVE%\domy

set graphsexist=0
set deletegraphs=0
set pluginsexist=0
set deleteplugins=0
if exist "%graphs%" set graphsexist=1
if exist "%plugins%" set pluginsexist=1
if not "%1" == "-c" python "%cfgm%" -vS
if errorlevel 1 (
	echo %~n0 - configuration failure - reinstallation required
	exit /b 1
	)
if exist "%graphs%" (
	if %graphsexist%==0 set deletegraphs=1
) else (
	set graphs=%DOMY%graphs
	)
if exist "%plugins%" (
	if %pluginsexist%==0 set deleteplugins=1
) else (
	set plugins=%DOMY%plugins
	)

:: set rootfolder - indirect method to compensate for variable expansion
for %%F in ("%DOMY:~0,-1%") do set rootfolder2=%%~dpF
for %%F in ("%rootfolder2:~0,-1%") do set rootfolder2=%%~dpFshare\domy
for %%F in ("%DOMY:~0,-1%") do set rootfolder3=%%~dpF
for %%F in ("%rootfolder3:~0,-1%") do set rootfolder3=%%~dpFshare\corpusfg
if not exist "%rootfolder%" (
	if exist "%rootfolder2%" (
		set rootfolder=%rootfolder2%
	) else (
		set rootfolder=%rootfolder3%
		)
	)
:: echo DOMY          %DOMY%
:: echo cfgm          %cfgm%
:: echo graphs        %graphs%
:: echo plugins       %plugins%
:: echo rootfolder    %rootfolder%
:: echo deletegraphs  %deletegraphs%
:: echo deleteplugins %deleteplugins%
:: call :leave
:: goto :EOF

:start
cls

echo Introduction:
echo.
echo This is the first of two demos. This demo runs five [5] example
echo "GRAPHS". GRAPHS are parallel tool-chains that extract, clean,
echo align parallel text, and otherwise prepare corpora and translation
echo memory data for use as SMT training data.
echo.
echo Example 1 converts HTML entities to UTF-8 characters
echo Example 2 creates sentence-aligned files from file-aligned data
echo Example 3 imports data from TMX files to CorpusFiltergraph
echo Example 4 exports data from CorpusFiltergraph to TMX files
echo Example 5 extracts bilingual data from individual files
echo.
echo You can find the GRAPHs and their config.ini files in:
echo %graphs%

echo.
echo Next: Instructions
if not "%1" == "-c" pause
cls

echo Instructions:
echo.
echo This is a wizard-style demo. It pauses before running an example
echo with a short description and the GRAPH's command line.
echo.
echo It pauses after running the example to show the command line,
echo the input and output of the example.
echo.
echo.

echo Next: Example 1 converts HTML/XML markup
if not "%1" == "-c" pause
cls

echo Example 1: clean HTML/XML markup
echo.
echo Cleaning HTML/XML data is an important task for all data preparation.
echo HTML and XML documents often include "entities" that represent characters.
echo For example, "&lt;" is "<" and "&gt;" is ">" and "&aacute;" is "". This GRAPH
echo converts these "entities" back to "normal" characters.
echo.
echo Command:  "%~d0> %BASE% clean-markup"
echo.
if not "%1" == "-c" pause
cls

echo Example 1:  clean HTML/XML markup
echo.
if exist "%graphs%\clean-markup\Demo - clean html xml entities.conf" (
	copy /y "%graphs%\clean-markup\config.ini" "%graphs%\clean-markup\.config.ini.tmp" > nul
	copy /y "%graphs%\clean-markup\Demo - clean html xml entities.conf" "%graphs%\clean-markup\config.ini" > nul
	python "%cfgm%" -v clean-markup
	if errorlevel 1 (
		set result=1
	) else (
		echo.
		echo Review
		echo Command:  "%~d0> %BASE% clean-markup"
		echo Input:    "file://%rootfolder%\CORPORA\sa\Examples\Unicode\entities\lm\en\en\character-entities.txt"
		echo Output:   "file://%rootfolder%\CORPORA.demo\qc\Examples\Unicode\entities\lm\en\en\character-entities.txt"
		echo.

		)
	copy /y "%graphs%\clean-markup\.config.ini.tmp" "%graphs%\clean-markup\config.ini" > nul
	del /q "%graphs%\clean-markup\.config.ini.tmp"
) else (
	echo "clean-markup" demo configuration is not installed.
	echo.
	)
if not %result%==0 (
	call :leave
	exit /b %result%
	)

echo Next: Example 2, create sentence-aligned data from aligned files
if not "%1" == "-c" pause
cls

echo Example 2: create sentence-aligned data from aligned files
echo.
echo This GRAPH starts with file-aligned data [fa] with one sentence
echo or phrase per line. The GRAPH matches source and target language
echo sentences to the [tm] output. Sentences without a match are saved
echo to the language model [lm] output.
echo.
echo Command:  "%~d0> %BASE% sa-champollion"
echo.
if not "%1" == "-c" pause
cls

echo Example 2: create sentence-aligned data from aligned files
echo.
echo Command:  "%~d0> %BASE% sa-champollion"
echo.
if exist "%graphs%\sa-champollion\Demo - align zh_cn-en sentences with Champollion Tool Kit.conf" (
	copy /y "%graphs%\sa-champollion\config.ini" "%graphs%\sa-champollion\.config.ini.tmp" > nul
	copy /y "%graphs%\sa-champollion\Demo - align zh_cn-en sentences with Champollion Tool Kit.conf" "%graphs%\sa-champollion\config.ini" > nul
	python "%cfgm%" -v sa-champollion
	if errorlevel 1 (
		set result=1
	) else (
		echo.
		echo Review
		echo Command:  "%~d0> %BASE% sa-champollion"
		echo Input1:   "file://%rootfolder%\CORPORA\fa\Examples\News\general\tm\zh_cn\zh_cn\CPP20000210000021.txt"
		echo Input2:   "file://%rootfolder%\CORPORA\fa\Examples\News\general\tm\zh_cn\en\CPP20000210000021.txt"
		echo Output1:  "file://%rootfolder%\CORPORA.demo\sa\Examples\News\general\tm\zh_cn\zh_cn\CPP20000210000021.txt"
		echo Output2:  "file://%rootfolder%\CORPORA.demo\sa\Examples\News\general\tm\zh_cn\en\CPP20000210000021.txt"
		echo.
		)
	copy /y "%graphs%\sa-champollion\.config.ini.tmp" "%graphs%\sa-champollion\config.ini" > nul
	del /q "%graphs%\sa-champollion\.config.ini.tmp"
) else (
	echo "sa-champollion" demo configuration is not installed.
	echo.
	)
if not %result%==0 (
	call :leave
	exit /b %result%
	)

echo Next: Example 3, import data from TMX files
if not "%1" == "-c" pause
cls

echo Example 3: import data TMX files
echo.
echo TMX [translation memory exchange] files were developed to exchange
echo translation memory data between companies, colleagues and systems.
echo This GRAPH imports aligned tmx data into the CorpusFiltergraph
echo folder hierarchy. These sample TMX files come from the DGT-TM
echo version 1 and maintain sentence alignment across 13 languages.
echo.
echo Command:  "%~d0> %BASE% import-tmx"
echo.
if not "%1" == "-c" pause
cls

echo Example 3: import data TMX files
echo.
echo Command:  "%~d0> %BASE% import-tmx"
echo.
if exist "%graphs%\import-tmx\Demo - import DGT TM 1.0 TMX files to corpus.conf" (
	copy /y "%graphs%\import-tmx\config.ini" "%graphs%\import-tmx\.config.ini.tmp" > nul
	copy /y "%graphs%\import-tmx\Demo - import DGT TM 1.0 TMX files to corpus.conf" "%graphs%\import-tmx\config.ini" > nul
	python "%cfgm%" -v import-tmx
	if errorlevel 1 (
		set result=1
	) else (
		echo.
		echo Review
		echo Command:  "%~d0> %BASE% import-tmx"
		echo Input1:   "file://%rootfolder%\RAW\European%20Commission\DGT_TM_1.0\Volume_1\21985A0705(01).tmx"
		echo Input2:   "file://%rootfolder%\RAW\European%20Commission\DGT_TM_1.0\Volume_1\22001D0118(18).tmx"
		echo Output1:  "file://%rootfolder%\CORPORA.demo\sa\European%20Commission\DGT_TM_1.0\Volume_1\tm\en_gb\"
		echo.
		)
	copy /y "%graphs%\import-tmx\.config.ini.tmp" "%graphs%\import-tmx\config.ini" > nul
	del /q "%graphs%\import-tmx\.config.ini.tmp"
) else (
	echo "import-tmx" demo configuration is not installed.
	echo.
	)
if not %result%==0 (
	call :leave
	exit /b %result%
	)

echo Next: Example 4, export data to TMX files
if not "%1" == "-c" pause
cls

echo Example 4: export data to TMX files
echo.
echo This GRAPH exports tm data to TMX files. Data from the CorpusFiltergarph
echo folder hierarchy can be shared with other translation systems.
echo.
echo Command:  "%~d0> %BASE% export-tmx"
echo.
if not "%1" == "-c" pause
cls

echo Example 4: export data to TMX files
echo.
echo Command:  "%~d0> %BASE% export-tmx"
echo.
if exist "%graphs%\export-tmx\Demo - export corpora to TMX files.conf" (
	copy /y "%graphs%\export-tmx\config.ini" "%graphs%\export-tmx\.config.ini.tmp" > nul
	copy /y "%graphs%\export-tmx\Demo - export corpora to TMX files.conf" "%graphs%\export-tmx\config.ini" > nul
	python "%cfgm%" -v export-tmx
	if errorlevel 1 (
		set result=1
	) else (
		echo.
		echo Review
		echo Command:  "%~d0> %BASE% export-tmx"
		echo Inputs:   "file://%rootfolder%\CORPORA.demo\sa\European%20Commission\DGT_TM_1.0\Volume_1\tm\en_gb\"
		echo Output1:  "file://%rootfolder%\RAW.demo\European%20Commission\DGT_TM_1.0\Volume_1\tm\en_gb\21985A0705(01).tmx.txt.tmx"
		echo Output2:  "file://%rootfolder%\RAW.demo\European%20Commission\DGT_TM_1.0\Volume_1\tm\en_gb\22001D0118(18).tmx.txt.tmx"
		echo.
		)
	copy /y "%graphs%\export-tmx\.config.ini.tmp" "%graphs%\export-tmx\config.ini" > nul
	del /q "%graphs%\export-tmx\.config.ini.tmp"
) else (
	echo "export-tmx" demo configuration is not installed.
	echo.
	)
if not %result%==0 (
	call :leave
	exit /b %result%
	)

echo Next: Example 5, extract bilingual dictionaries from individual files
if not "%1" == "-c" pause
cls

echo Example 5: extract bilingual dictionaries from individual files
echo.
echo This is an example of a custom GRAPH. Users and PTTools can create
echo custom GRAPHS for special data-cleaning purposes. This example's
echo input file has parenthetical entries in-line with the main text.
echo This GRAPH removes the parenthetical entries from the original files
echo and saves them as new parallel dictionary files.
echo.
echo Command:  "%~d0> %BASE% extract-dictionary"
echo.
if not "%1" == "-c" pause
cls

echo Example 5: extract bilingual dictionaries from individual files
echo.
echo Command:  "%~d0> %BASE% extract-dictionary"
echo.
if exist "%graphs%\extract-dictionary\Demo - extract custom dictionaries from zh_uk-en corpus.conf" (
	copy /y "%graphs%\extract-dictionary\config.ini" "%graphs%\extract-dictionary\.config.ini.tmp" > nul
	copy /y "%graphs%\extract-dictionary\Demo - extract custom dictionaries from zh_uk-en corpus.conf" "%graphs%\extract-dictionary\config.ini" > nul
	python "%cfgm%" -v extract-dictionary
	if errorlevel 1 (
		set result=1
	) else (
		echo.
		echo Review
		echo Command:  "%~d0> %BASE% extract-dictionary"
		echo Input1:   "file://%rootfolder%\CORPORA\sa\Examples\Legislation\statutes\tm\zh_hk\zh_hk\hklaws.txt"
		echo Input2:   "file://%rootfolder%\CORPORA\sa\Examples\Legislation\statutes\tm\zh_hk\en\hklaws.txt"
		echo Outputs:  "file://%rootfolder%\CORPORA.demo\qc\Examples\Legislation\statutes\"
		echo Output1:  "file://%rootfolder%\CORPORA.demo\qc\Examples\Legislation\statutes\tm\zh_hk\zh_hk\hklaws.txt"
		echo Output2:  "file://%rootfolder%\CORPORA.demo\qc\Examples\Legislation\statutes\tm\zh_hk\en\hklaws.txt"
		echo Output3:  "file://%rootfolder%\CORPORA.demo\qc\Examples\Legislation\statutes\tm-dictionary\zh_hk\zh_hk\hklaws.txt"
		echo Output4:  "file://%rootfolder%\CORPORA.demo\qc\Examples\Legislation\statutes\tm-dictionary\zh_hk\en\hklaws.txt"
		echo.
		)
	copy /y "%graphs%\extract-dictionary\.config.ini.tmp" "%graphs%\extract-dictionary\config.ini" > nul
	del /q "%graphs%\extract-dictionary\.config.ini.tmp"
) else (
	echo "extract-dictionary" demo configuration is not installed.
	echo.
	)
if not %result%==0 (
	call :leave
	exit /b %result%
	)

echo Next: Review
if not "%1" == "-c" pause
cls

echo Review:
echo.
echo Examples in Demo-1.bat extracted, cleaned and aligned parallel text data.
echo.
echo Example 1 converted HTML entities to UTF-8 characters
echo Example 2 created sentence-aligned files from file-aligned data
echo Example 3 imported data from TMX files to CorpusFiltergraph
echo Example 4 exported data from CorpusFiltergraph to TMX files
echo Example 5 extracted bilingual data from individual files
echo.
echo NOTE: All outputs were saved to sub-folders in
echo   "%rootfolder%\CORPORA.demo\*" or 
echo   "%rootfolder%\RAW.demo\*".
echo   The examples in the next demo, "demo-2.bat" in DoMY CE, continue
echo   with the outputs from this demo. It is safe to delete these demo
echo   root folders after running "demo-2.bat" in DoMY CE.
echo.
echo Demo-2.bat prepares two data BUILD sets from the cleaned data and
echo trains two translation engines. You can start then DoMY CE demo
echo with the command "demo-2.bat"
echo.

echo Next: Repeat demo-1.bat or run demo-2.bat (requires DoMY CE)

call :leave
exit /b 0

:leave
	if %deletegraphs%==1 ( rd /s /q "%graphs%" 2>nul )
	if %deleteplugins%==1 ( rd /s /q "%plugins%" 2>nul )
	goto :EOF

:: CorpusFiltergraph v4.5.330
:: Copyright  2010-2011 Precision Translation Tools Co., Ltd.

:: This program is free software: you can redistribute it and\or modify
:: it under the terms of the GNU Lesser General Public License as published by
:: the Free Software Foundation, either version 3 of the License, or
:: (at your option) any later version.

:: This program is distributed in the hope that it will be useful,
:: but WITHOUT ANY WARRANTY; without even the implied warranty of
:: MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
:: GNU Lesser General Public License for more details.

:: You should have received a copy of the GNU Lesser General Public License
:: along with this program.  If not, see http:\\www.gnu.org\licenses\

:: For more information, please contact Precision Translation Tools Co., Ltd.
:: at: http:\\www.precisiontranslationtools.com
